"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const runtimeConfig_browser_1 = require("./utils/runtimeConfig.browser");
const serviceIds_1 = require("./types/serviceIds");
class Client {
    constructor(config) {
        const _config = (0, runtimeConfig_browser_1.getRuntimeConfig)(config);
        this.config = _config;
        if (document.readyState === 'complete') {
            this.initFrameConduit();
        }
        else {
            document.addEventListener('readystatechange', () => {
                if (document.readyState === 'complete') {
                    this.initFrameConduit();
                }
            });
        }
        this.config.requestHandler.setRuntimeConfig(this.config);
    }
    initFrameConduit() {
        var _a, _b;
        if (this.config.frameWindow || this.config.instanceUrl.includes((_a = window === null || window === void 0 ? void 0 : window.location) === null || _a === void 0 ? void 0 : _a.origin))
            return;
        const iframe = document.querySelector('iframe[src*="wisdom-v2"]');
        if (iframe && iframe.contentWindow) {
            this.config.frameWindow = iframe;
        }
        else {
            try {
                let container = document.querySelector('wisdom-container');
                if (!container) {
                    container = document.createElement('div');
                    container.id = 'wisdom-container';
                    document.body.appendChild(container);
                }
                (_b = window === null || window === void 0 ? void 0 : window.connect) === null || _b === void 0 ? void 0 : _b.agentApp.initApp(serviceIds_1.ServiceIds.Wisdom, 'wisdom-container', `${this.config.instanceUrl}/wisdom-v2/?theme=hidden_page`, {
                    style: 'display: none',
                });
                this.config.frameWindow = document.getElementById(serviceIds_1.ServiceIds.Wisdom);
            }
            catch (e) {
                console.error('There was an error initializing Wisdom');
            }
        }
    }
    async call(command, options) {
        const handler = command.resolveRequestHandler(this.config, options);
        return handler().then((response) => response);
    }
}
exports.Client = Client;
