"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseAmzTarget = exports.buildAmzTarget = void 0;
const clientMethods_1 = require("../types/clientMethods");
const widgetServices_1 = require("../types/widgetServices");
const buildAmzTarget = (clientMethod, { serviceId }) => {
    return {
        'x-amz-target': `AgentAppService.${widgetServices_1.WidgetServices[serviceId]}.${clientMethod}`,
    };
};
exports.buildAmzTarget = buildAmzTarget;
const parseAmzTarget = (xAmzTarget) => {
    const [prefix, widgetService, clientMethod] = (xAmzTarget === null || xAmzTarget === void 0 ? void 0 : xAmzTarget.split('.')) || [];
    if (!prefix || prefix !== 'AgentAppService') {
        throw new Error('Unsupported service prefix.');
    }
    if (!widgetService || !Object.values(widgetServices_1.WidgetServices).includes(widgetService)) {
        throw new Error('Unsupported service.');
    }
    let serviceMethods;
    switch (widgetService) {
        case widgetServices_1.WidgetServices.Wisdom:
            serviceMethods = clientMethods_1.WisdomMethods;
            break;
        case widgetServices_1.WidgetServices.AgentApp:
            serviceMethods = clientMethods_1.AgentAppMethods;
            break;
        case widgetServices_1.WidgetServices.Acs:
            serviceMethods = clientMethods_1.AcsMethods;
            break;
        case widgetServices_1.WidgetServices.Lcms:
            serviceMethods = clientMethods_1.LcmsMethods;
            break;
    }
    if (!clientMethod || !Object.values(serviceMethods).includes(clientMethod)) {
        throw new Error('Unsupported client method.');
    }
    return clientMethod;
};
exports.parseAmzTarget = parseAmzTarget;
