import { __assign, __awaiter, __generator, __values } from "tslib";
import { fetchWithChannel, subscribeToChannel } from './utils/communicationProxy';
import { Commands } from './types/command';
import { parseAmzTarget } from './utils/buildAmzTarget';
var FetchHttpHandler = (function () {
    function FetchHttpHandler(config) {
        this.config = config !== null && config !== void 0 ? config : {};
        subscribeToChannel(this.channelRequestHandler.bind(this));
    }
    FetchHttpHandler.prototype.setRuntimeConfig = function (config) {
        this.runtimeConfig = config;
    };
    FetchHttpHandler.prototype.responseHandler = function (response) {
        return __awaiter(this, void 0, void 0, function () {
            var status, statusText, ok, headers, body, fetchHeaders, transformedHeaders, _a, _b, pair, hasReadableStream, reader, res, isDone, _c, done, value, prior;
            var e_1, _d;
            return __generator(this, function (_e) {
                switch (_e.label) {
                    case 0:
                        status = response.status, statusText = response.statusText, ok = response.ok, headers = response.headers, body = response.body;
                        fetchHeaders = headers;
                        transformedHeaders = {};
                        try {
                            for (_a = __values(fetchHeaders.entries()), _b = _a.next(); !_b.done; _b = _a.next()) {
                                pair = _b.value;
                                transformedHeaders[pair[0]] = pair[1];
                            }
                        }
                        catch (e_1_1) { e_1 = { error: e_1_1 }; }
                        finally {
                            try {
                                if (_b && !_b.done && (_d = _a.return)) _d.call(_a);
                            }
                            finally { if (e_1) throw e_1.error; }
                        }
                        hasReadableStream = body !== undefined;
                        if (!hasReadableStream) {
                            return [2, response.blob()
                                    .then(function () {
                                    return {
                                        status: status,
                                        statusText: statusText,
                                        ok: ok,
                                        headers: transformedHeaders,
                                        body: response.json(),
                                    };
                                })];
                        }
                        reader = body.getReader();
                        res = new Uint8Array(0);
                        isDone = false;
                        _e.label = 1;
                    case 1:
                        if (!!isDone) return [3, 3];
                        return [4, reader.read()];
                    case 2:
                        _c = _e.sent(), done = _c.done, value = _c.value;
                        if (value) {
                            prior = res;
                            res = new Uint8Array(prior.length + value.length);
                            res.set(prior);
                            res.set(value, prior.length);
                        }
                        isDone = done;
                        return [3, 1];
                    case 3: return [2, {
                            status: status,
                            statusText: statusText,
                            ok: ok,
                            headers: transformedHeaders,
                            body: JSON.parse(new TextDecoder('utf8').decode(res)),
                        }];
                }
            });
        });
    };
    FetchHttpHandler.prototype.channelRequestHandler = function (_, options) {
        return __awaiter(this, void 0, void 0, function () {
            var headers, body, amzTarget, clientMethod, Command, clientCommand;
            return __generator(this, function (_a) {
                try {
                    headers = options.headers, body = options.body;
                    amzTarget = headers === null || headers === void 0 ? void 0 : headers['x-amz-target'];
                    clientMethod = parseAmzTarget(amzTarget);
                    Command = Commands[clientMethod];
                    clientCommand = new Command(JSON.parse(body));
                    return [2, this.handle(clientCommand.serialize(this.runtimeConfig), {})];
                }
                catch (e) {
                    console.log('Something went wrong during request.', e);
                    return [2, Promise.reject(e)];
                }
                return [2];
            });
        });
    };
    FetchHttpHandler.prototype.fetchRequestHandler = function (url, options) {
        return __awaiter(this, void 0, void 0, function () {
            var response, e_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4, fetch(url, options)];
                    case 1:
                        response = _a.sent();
                        return [2, this.responseHandler(response)];
                    case 2:
                        e_2 = _a.sent();
                        console.log('Something went wrong during request.', e_2);
                        return [2, Promise.reject(e_2)];
                    case 3: return [2];
                }
            });
        });
    };
    FetchHttpHandler.prototype.fetchRequest = function (url, options, frameWindow) {
        return __awaiter(this, void 0, void 0, function () {
            var response, e_3;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 4, , 5]);
                        if (!frameWindow) return [3, 2];
                        return [4, fetchWithChannel(frameWindow.contentWindow, frameWindow.src, { url: url, options: options })];
                    case 1:
                        response = _a.sent();
                        return [2, Promise.resolve(response)];
                    case 2: return [2, this.fetchRequestHandler(url, options)];
                    case 3: return [3, 5];
                    case 4:
                        e_3 = _a.sent();
                        console.log('Something went wrong during request.', e_3);
                        return [2, Promise.reject(e_3)];
                    case 5: return [2];
                }
            });
        });
    };
    FetchHttpHandler.prototype.requestTimeout = function (timeoutInMs) {
        return new Promise(function (_, reject) {
            if (timeoutInMs) {
                setTimeout(function () {
                    var timeoutError = new Error("Request did not complete within ".concat(timeoutInMs, " ms."));
                    timeoutError.name = "TimeoutError";
                    reject(timeoutError);
                }, timeoutInMs);
            }
        });
    };
    FetchHttpHandler.prototype.abortRequest = function (abortSignal) {
        return new Promise(function (_, reject) {
            if (abortSignal) {
                abortSignal.onabort = function () {
                    var abortError = new Error('Request aborted.');
                    abortError.name = 'AbortError';
                    reject(abortError);
                };
            }
        });
    };
    FetchHttpHandler.prototype.handle = function (request, options) {
        var abortSignal = (options || {}).abortSignal;
        var requestTimeout = (this.config || {}).requestTimeout;
        if (abortSignal === null || abortSignal === void 0 ? void 0 : abortSignal.aborted) {
            var abortError = new Error("Request aborted");
            abortError.name = "AbortError";
            return Promise.reject(abortError);
        }
        var protocol = request.protocol, hostname = request.hostname, port = request.port, path = request.path, method = request.method, headers = request.headers, body = request.body, frameWindow = request.frameWindow;
        var url = "".concat(protocol, "//").concat(hostname).concat(port ? ":".concat(port) : '').concat(path);
        var requestOptions = __assign({ method: method, headers: headers, body: body }, (!frameWindow && AbortController && abortSignal && { signal: abortSignal }));
        return Promise.race([
            this.fetchRequest(url, requestOptions, frameWindow),
            this.requestTimeout(requestTimeout),
            this.abortRequest(abortSignal),
        ]);
    };
    return FetchHttpHandler;
}());
export { FetchHttpHandler };
