import { __awaiter, __generator } from "tslib";
import { MessageChannel } from 'worker_threads';
import { WisdomClient } from './wisdomClient';
import { GetAuthorizedWidgetsForUser } from './commands/getAuthorizedWidgetsForUser';
import { GetContent } from './commands/getContent';
import { GetRecommendations } from './commands/getRecommendations';
import { ListIntegrationAssociations } from './commands/listIntegrationAssociations';
import { NotifyRecommendationsReceived } from './commands/notifyRecommendationsReceived';
import { QueryAssistant } from './commands/queryAssistant';
import { SearchSessions } from './commands/searchSessions';
import { GetContact } from './commands/getContact';
describe('WisdomClient', function () {
    var client;
    var instanceUrl = 'https://foo.amazonaws.com';
    var mockHandler = jest.fn(function (args) { return Promise.resolve('success response'); });
    var mockResolveRequestHandler = jest.fn(function (args) { return mockHandler; });
    delete global.location;
    global.location = { href: 'https://foo.amazonaws.com' };
    global.MessageChannel = MessageChannel;
    beforeEach(function () {
        jest.clearAllMocks();
        client = new WisdomClient({
            instanceUrl: instanceUrl,
        });
    });
    it('should properly construct the endpoint from the instanceUrl when not provided', function () {
        client = new WisdomClient({
            instanceUrl: instanceUrl,
            endpoint: 'https://localhost:4000/example-api/',
        });
        expect(client.config.endpoint).toEqual('https://localhost:4000/example-api/');
        var cfInstanceUrl = 'https://foo.com.awsapps.com/connect/';
        client = new WisdomClient({
            instanceUrl: cfInstanceUrl,
        });
        expect(client.config.endpoint).toEqual('https://foo.com.awsapps.com/connect/agent-app/api');
        var nginxInstanceUrl = 'https://foo.my.connect.aws';
        client = new WisdomClient({
            instanceUrl: nginxInstanceUrl,
        });
        expect(client.config.endpoint).toEqual('https://foo.my.connect.aws/agent-app/api');
    });
    it('should return a response promise when calling getAuthorizedWidgetsForUser', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    GetAuthorizedWidgetsForUser.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.getAuthorizedWidgetsForUser({})).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling getContent', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    GetContent.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.getContent({
                            contentId: 'c6ca58b9-b046-4664-ba63-da17f51fc332',
                            knowledgeBaseId: 'f9b5fa90-b3ce-45c9-9967-582c87074864',
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling getRecommendations', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    GetRecommendations.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.getRecommendations({
                            assistantId: 'b5b0e4af-026e-4472-9371-d171a9fdf75a',
                            sessionId: '249bbb30-aede-42a8-be85-d8483c317686',
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling listIntegrationAssociations', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    ListIntegrationAssociations.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.listIntegrationAssociations({
                            InstanceId: 'b5b0e4af-026e-4472-9371-d171a9fdf75a',
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling notifyRecommendationsReceived', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    NotifyRecommendationsReceived.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.notifyRecommendationsReceived({
                            assistantId: 'b5b0e4af-026e-4472-9371-d171a9fdf75a',
                            sessionId: '249bbb30-aede-42a8-be85-d8483c317686',
                            recommendationIds: [],
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling queryAssistant', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    QueryAssistant.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.queryAssistant({
                            assistantId: 'b5b0e4af-026e-4472-9371-d171a9fdf75a',
                            maxResults: 10,
                            queryText: 'aws',
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling searchSessions', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    SearchSessions.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.searchSessions({
                            assistantId: 'b5b0e4af-026e-4472-9371-d171a9fdf75a',
                            searchExpression: {
                                filters: [
                                    {
                                        operator: 'equals',
                                        field: 'name',
                                        value: '249bbb30-aede-42a8-be85-d8483c317686',
                                    },
                                ],
                            },
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('should return a response promise when calling getContact', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    GetContact.prototype.resolveRequestHandler = mockResolveRequestHandler;
                    return [4, expect(client.getContact({
                            awsAccountId: '85be2a14-94d7-41f2-835e-85368acb55df',
                            instanceId: 'b5b0e4af-026e-4472-9371-d171a9fdf75a',
                            contactId: '249bbb30-aede-42a8-be85-d8483c317686',
                        })).resolves.toEqual('success response')];
                case 1:
                    _a.sent();
                    return [2];
            }
        });
    }); });
});
