export declare enum ContentStatus {
    ACTIVE = "ACTIVE",
    CREATE_FAILED = "CREATE_FAILED",
    CREATE_IN_PROGRESS = "CREATE_IN_PROGRESS",
    DELETED = "DELETED",
    DELETE_FAILED = "DELETE_FAILED",
    DELETE_IN_PROGRESS = "DELETE_IN_PROGRESS",
    UPDATE_FAILED = "UPDATE_FAILED"
}
export declare enum FilterField {
    NAME = "NAME"
}
export declare enum FilterOperator {
    EQUALS = "EQUALS"
}
export declare enum RelevanceLevel {
    HIGH = "HIGH",
    LOW = "LOW",
    MEDIUM = "MEDIUM"
}
export declare enum IntegrationTypes {
    EVENT = "EVENT",
    VOICE_ID = "VOICE_ID",
    PINPOINT_APP = "PINPOINT_APP",
    WISDOM_ASSISTANT = "WISDOM_ASSISTANT",
    WISDOM_KNOWLEDGE_BASE = "WISDOM_KNOWLEDGE_BASE"
}
export declare enum RecommendationTriggerType {
    QUERY = "QUERY"
}
export declare enum RecommendationSourceType {
    ISSUE_DETECTION = "ISSUE_DETECTION",
    RULE_EVALUATION = "RULE_EVALUATION",
    OTHER = "OTHER"
}
export interface ContentData {
    contentArn: string;
    contentId: string;
    knowledgeBaseArn: string;
    knowledgeBaseId: string;
    name: string;
    revisionId: string;
    title: string;
    contentType: string;
    status: ContentStatus | string;
    metadata: {
        [key: string]: string;
    };
    tags?: {
        [key: string]: string;
    };
    linkOutUri?: string;
    url: string;
    urlExpiry: Date;
}
export interface ContentReference {
    knowledgeBaseArn?: string;
    knowledgeBaseId?: string;
    contentArn?: string;
    contentId?: string;
}
export interface Document {
    contentReference: ContentReference;
    title?: DocumentText;
    excerpt?: DocumentText;
}
export interface DocumentText {
    text?: string;
    highlights?: Highlight[];
}
export interface Filter {
    field: FilterField | string;
    operator: FilterOperator | string;
    value: string;
}
export interface Highlight {
    beginOffsetInclusive?: number;
    endOffsetExclusive?: number;
}
export interface NotifyRecommendationsReceivedError {
    recommendationId?: string;
    message?: string;
}
export interface RecommendationData {
    recommendationId: string;
    document: Document;
    relevanceScore?: number;
    relevanceLevel?: RelevanceLevel | string;
}
export interface QueryRecommendationTriggerData {
    text?: string;
}
export interface RecommendationTriggerData {
    query?: QueryRecommendationTriggerData;
}
export interface RecommendationTrigger {
    id: string;
    type: RecommendationTriggerType;
    source: RecommendationSourceType;
    data: RecommendationTriggerData;
    recommendationIds: string[];
}
export interface ResultData {
    resultId: string;
    document: Document;
    relevanceScore?: number;
}
export interface SearchExpression {
    filters: Filter[];
}
export interface SessionSummary {
    sessionId: string;
    sessionArn: string;
    assistantId: string;
    assistantArn: string;
}
export interface GetContentRequest {
    contentId: string;
    knowledgeBaseId: string;
}
export interface GetContentResponse {
    content?: ContentData;
}
export interface GetRecommendationsRequest {
    assistantId: string;
    sessionId: string;
    maxResults?: number;
    waitTimeSeconds?: number;
}
export interface GetRecommendationsResponse {
    recommendations: RecommendationData[];
    triggers?: [];
}
export interface NotifyRecommendationsReceivedRequest {
    assistantId: string;
    sessionId: string;
    recommendationIds: string[];
}
export interface NotifyRecommendationsReceivedResponse {
    recommendationIds?: string[];
    errors?: NotifyRecommendationsReceivedError[];
}
export interface QueryAssistantRequest {
    assistantId: string;
    queryText: string;
    nextToken?: string;
    maxResults?: number;
}
export interface QueryAssistantResponse {
    results: ResultData[];
    nextToken?: string;
}
export interface SearchSessionsRequest {
    nextToken?: string;
    maxResults?: number;
    assistantId: string;
    searchExpression: SearchExpression;
}
export interface SearchSessionsResponse {
    sessionSummaries: SessionSummary[];
    nextToken?: string;
}
export interface GetAuthorizedWidgetsForUserRequest {
}
export interface GetAuthorizedWidgetsForUserResponse {
    widgets?: {
        [widget: string]: string[];
    };
    widgetsDataPermission?: {
        name: string;
        endpoint: string;
        allowedTopicSubscriptions: string[];
        allowedTopicPublications: string[];
        enableLifeCycleEvents: boolean;
        version: string;
    }[];
}
export interface ListIntegrationAssociationsRequest {
    InstanceId: string;
    IntegrationType?: IntegrationTypes;
    StartingToken?: string;
    PageSize?: number;
    MaxItems?: number;
}
export interface ListIntegrationAssociationsResponse {
    IntegrationAssociationSummaryList: {
        IntegrationAssociationId: string;
        IntegrationAssociationArn: string;
        InstanceId: string;
        IntegrationType: string;
        IntegrationArn: string;
        SourceApplicationUrl: string;
        SourceApplicationName: string;
        SourceType: string;
    }[];
}
export interface GetContactRequest {
    awsAccountId: string;
    instanceId: string;
    contactId: string;
}
export interface GetContactResponse {
    contactFeature: {
        wisdomFeatures: {
            wisdomConfig: {
                sessionArn: string;
            };
        };
    };
}
