import { Client, ClientConfiguration, ClientResolvedConfig } from './client';
import { GetAuthorizedWidgetsForUserInput, GetAuthorizedWidgetsForUserOutput, GetContentInput, GetContentOutput, GetRecommendationsInput, GetRecommendationsOutput, ListIntegrationAssociationsInput, ListIntegrationAssociationsOutput, NotifyRecommendationsReceivedInput, NotifyRecommendationsReceivedOutput, QueryAssistantInput, QueryAssistantOutput, SearchSessionsInput, SearchSessionsOutput, GetContactInput, GetContactOutput } from './commands';
import { RequestHandler } from './types/requestHandler';
import { HttpResponse, HttpHandlerOptions } from './types/http';
export type ServiceInputTypes = GetAuthorizedWidgetsForUserInput | GetContentInput | GetRecommendationsInput | ListIntegrationAssociationsInput | NotifyRecommendationsReceivedInput | QueryAssistantInput | SearchSessionsInput | GetContactInput;
export type ServiceOutputTypes = GetAuthorizedWidgetsForUserOutput | GetContentOutput | GetRecommendationsOutput | ListIntegrationAssociationsOutput | NotifyRecommendationsReceivedOutput | QueryAssistantOutput | SearchSessionsOutput | GetContactOutput;
export interface WisdomClientConfig extends ClientConfiguration {
    requestHandler?: RequestHandler<any, any, HttpHandlerOptions>;
}
export type WisdomClientResolvedConfig = ClientResolvedConfig;
export declare class WisdomClient extends Client<HttpHandlerOptions, ServiceInputTypes, ServiceOutputTypes, WisdomClientResolvedConfig> {
    constructor(config: WisdomClientConfig);
    getAuthorizedWidgetsForUser(args: GetAuthorizedWidgetsForUserInput, options?: HttpHandlerOptions): Promise<HttpResponse<GetAuthorizedWidgetsForUserOutput>>;
    getContent(args: GetContentInput, options?: HttpHandlerOptions): Promise<HttpResponse<GetContentOutput>>;
    getRecommendations(args: GetRecommendationsInput, options?: HttpHandlerOptions): Promise<HttpResponse<GetRecommendationsOutput>>;
    listIntegrationAssociations(args: ListIntegrationAssociationsInput, options?: HttpHandlerOptions): Promise<HttpResponse<ListIntegrationAssociationsOutput>>;
    notifyRecommendationsReceived(args: NotifyRecommendationsReceivedInput, options?: HttpHandlerOptions): Promise<HttpResponse<NotifyRecommendationsReceivedOutput>>;
    queryAssistant(args: QueryAssistantInput, options?: HttpHandlerOptions): Promise<HttpResponse<QueryAssistantOutput>>;
    searchSessions(args: SearchSessionsInput, options?: HttpHandlerOptions): Promise<HttpResponse<SearchSessionsOutput>>;
    getContact(args: GetContactInput, options?: HttpHandlerOptions): Promise<HttpResponse<GetContactOutput>>;
}
